from fastapi import FastAPI
from users import add_user_routers, User
from db import database, engine, Base, DbSession
from starlette.requests import Request
from routes import router as api_router
import models


def get_app() -> FastAPI:
    application = FastAPI(title="swimtracker", debug=True, version="0.1")
    application.include_router(api_router)
    add_user_routers(application)
    return application


app = get_app()


@app.middleware("http")
async def db_session_middleware(request: Request, call_next):
    request.state.db = DbSession()
    response = await call_next(request)
    request.state.db.close()
    return response


@app.on_event("startup")
async def startup() -> None:
    print("creating")
    Base.metadata.create_all(engine)
    if not database.is_connected:
        await database.connect()


@app.on_event("shutdown")
async def shutdown() -> None:
    if database.is_connected:
        await database.disconnect()
