from db import Base
from sqlalchemy import Column, Integer, Index, LargeBinary, ForeignKey, and_, or_
from typing import Tuple


class Session(Base):
    __tablename__ = "session"

    device_id = Column(Integer, primary_key=True)
    start_time = Column(Integer, primary_key=True)
    data = Column(LargeBinary(1024 * 1024 * 2), nullable=False)
    user = Column(ForeignKey("user.id"), nullable=False)

    value_right_shift = Column(Integer)
    tare_value = Column(Integer)
    kg_factor = Column(Integer)

    Index('device_id', 'start_time', unique=True)


class FriendRequest(Base):
    __tablename__ = "friend_request"
    requesting_user = Column(ForeignKey("user.id"), primary_key=True)
    receiving_user = Column(ForeignKey("user.id"), primary_key=True)


class Friendship(Base):
    __tablename__ = "friendship"
    user_id = Column(ForeignKey("user.id"), primary_key=True)
    friend_id = Column(ForeignKey("user.id"), primary_key=True)

    @staticmethod
    def befriend(db, userid1, userid2):
        db.add(Friendship(user_id=userid1, friend_id=userid2))

    @staticmethod
    def are_friends(db, userid1, userid2):
        query_filter = or_(
            and_(Friendship.user_id == userid1, Friendship.friend_id == userid2),
            and_(Friendship.user_id == userid2, Friendship.friend_id == userid1),
        )
        return db.query(Friendship).filter(query_filter).count() > 0