from typing import Optional, List
from pydantic import BaseModel, conint, UUID4
from pydantic.networks import EmailStr


class SessionBase(BaseModel):
    device_id: int
    start_time: conint(gt=1546297200)
    data: str

    value_right_shift: Optional[conint(ge=0, le=32)]
    tare_value: Optional[conint(ge=0)]
    kg_factor: Optional[conint(ge=0)]

    class Config:
        orm_mode = True


class UserInfo(BaseModel):
    id: UUID4
    email: EmailStr

    class Config:
        orm_mode = True


class Session(SessionBase):
    user: UUID4


class FriendRequestCreate(BaseModel):
    other_user_id: int


class FriendsInfo(BaseModel):
    incoming_requests: List[UserInfo]
    outgoing_requests: List[UserInfo]

    class Config:
        orm_mode = True
